Install
=======

The RKI COVID-19 API Python Client requires Python 3.6, 3.7, 3.8, or 3.9. But first, make sure you have the latest version of ``pip``
installed.

Install the Released Version
----------------------------

Download and install the current release of ``covid19pyclient`` from the Python Packaging Index::

    $ pip install covid19pyclient

Alternatively, you can download and install ``covid19pyclient`` from github::

    $ pip install git+https://github.com/NiklasTiede/Covid19PyClient
